@@ -1,4 +1,4 @@
-#!/usr/bin/perl
+#!/usr/bin/env perl
 #
 
 ##########################################################################################################################
@@ -36,12 +36,12 @@ my $species;                          # species name
 my $hints;                            # hints file name
 my $havehints=0;                      # have hints at all or not?
 my $estali;                           # est file for make UTR-Training
-my $positionWD=cwd();                 # workding superdirectory where program is called from
+my $positionWD=cwd();                 # working superdirectory where program is called from
 my $pasa='';                          # switch it on to create training set, est set, hints file with PASA
-my $pasapolyAhints;                   # use pasa Poly A hints as hints for the prediction
+my $pasapolyAhints;                   # use PASA Poly A hints as hints for the prediction
 my $fasta_cdna;                       # fasta file for PASA
 my $verbose=2;                        # verbose level
-my $singleCPU=0;                      # run everything sequentially whithout interruption
+my $singleCPU=0;                      # run everything sequentially without interruption
 my $maxIntronLen = 100000;            # maximal length of an intron, used by PASA and BLAT
 my $noninteractive;                   # parameter for autoAugPred.pl
 my $cname="fe";                       # parameter for autoAugPred.pl:cluster name
@@ -50,7 +50,7 @@ my $optrounds=1;                      # optimization rounds
 my $useGMAPforPASA=0;                 # use GMAP instead of BLAT (only for PASA)
 my $useexisting=0;                    # start with and change existing config, parameter and result files
 my $utr=1;                            # default value: with "utr" if cDNA exists
-my $flanking_DNA='';                  # length of flanking DNA, defaul value is min{ave. gene length, 10000}
+my $flanking_DNA='';                  # length of flanking DNA, default value is min{ave. gene length, 10000}
 my $help=0;                           # print usage
 my $useexistingopt = "";
 my $autoAugDir_abinitio;
@@ -73,12 +73,12 @@ my $string;          		      # temp string for perl-scripts, which will be calle
 
 my $usage =  <<_EOH_;
 
-Function: train AUGUSTUS and run AUGUSTUS completly and automatically
+Function: train AUGUSTUS and run AUGUSTUS completely and automatically
 
 Usage:
 
 autoAug.pl [OPTIONS] --species=sname --genome=genome.fa --cdna=cdna.fa --trainingset=genesfile
-autoAug.pl [OPTIONS] --species=sname --genome=genome.fa --cdna=cdna.fa --pasa
+autoAug.pl [OPTIONS] --species=sname --genome=genome.fa --cdna=cdna.fa --pasa --useGMAPforPASA
 autoAug.pl [OPTIONS] --species=sname --genome=genome.fa --trainingset=genesfile [--estali=cdna.psl] [--hints=hints.gff]
 
 --genome=fasta                      fasta file with DNA sequences for training
@@ -98,7 +98,7 @@ options:
                                     Default: current working directory
 --singleCPU                         run the complete program sequentially instead of parallel execution of jobs on a cluster
 --noninteractive                    bypass all manual interaction when using a SGE cluster
---cname=yourClusterName             cluster name, only use it wenn "noninteractive" default:fe
+--cname=yourClusterName             cluster name, only use it when "noninteractive" default:fe
 --index=i                           step index, default:0 
 --optrounds=n                       optimization rounds - each meta parameter is optimized this often (default 1)
 --maxIntronLen=n                    maximal length of an intron as used by PASA and BLAT, not by AUGUSTUS (default 100000)
@@ -179,7 +179,7 @@ die("$AUGUSTUS_CONFIG_PATH/species/$species already exists. Choose another speci
 $genome = checkFile($genome, "fasta", $usage);
 check_fasta_headers($genome);
 
-# show error information and stop the program if the specified $positionWD coudn't be found
+# show error information and stop the program if the specified $positionWD couldn't be found
 # overwrite $positionWD with absolute path
 $positionWD=relToAbs($positionWD);         
 die("Error: Did not find the directory $positionWD! Please specify a valid one for \"workingdir\"! \n") unless (-d $positionWD);
@@ -309,7 +309,7 @@ sub training_set_dirs {
 	print "3 mkdir $_\n" if ($verbose>=3);
     }
  
-    print "2 All necessary directories have been created unter $trainDir.\n" if ($verbose>=2);
+    print "2 All necessary directories have been created under $trainDir.\n" if ($verbose>=2);
 
     # build symbolic link for $genome
 
@@ -363,14 +363,14 @@ sub construct_training_set{
 
     if (!uptodate([$fasta_cdna], ["transcripts.fasta"])){
 	print "3 ln -fs $fasta_cdna transcripts.fasta\n" if ($verbose>=3);
-	system("ln -fs $fasta_cdna transcripts.fasta")==0 or die ("failed to execute: $!\n");
+	system("ln -fs $fasta_cdna transcripts.fasta")==0 or die ("failed to execute: ln -fs $fasta_cdna transcripts.fasta\n");
     }
 
     if (!uptodate(["transcripts.fasta"], ["transcripts.fasta.clean"])){
 	count_fasta_entries("$trainDir/pasa/transcripts.fasta");
-	$perlCmdString="perl $PASAHOME/seqclean/seqclean/seqclean transcripts.fasta 1>seqclean.stdout 2>seqclean.stderr";
+	$perlCmdString="seqclean transcripts.fasta 1>seqclean.stdout 2>seqclean.stderr";
 	print "2 Running $perlCmdString ..." if ($verbose>=2);
-	system("$perlCmdString")==0 or die ("failed to execute: $!\n");
+	system("$perlCmdString")==0 or die ("failed to execute: $perlCmdString\n");
 	print " Finished!\n" if ($verbose>=2);
     } else {
 	print ("2 Skipping seqclean. Using existing transcripts.fasta.clean.\n") if ($verbose>=2);
@@ -389,7 +389,9 @@ sub construct_training_set{
 	open(CONFIG, "alignAssembly.config") or die ("Cannot open file alignAssembly.config!\n");
 	open(TEMP, ">temp") or die("\nCannot open file temp\n");
 	while(<CONFIG>){
-	    s/<__MYSQLDB__>/$pasaDBname/;
+	    s/MYSQLDB=<__MYSQLDB__>/MYSQLDB=$pasaDBname/;    # the database name used in old PASA versions
+	    s/DATABASE=<__DATABASE__>/DATABASE=$pasaDBname/; # the database name used in newer PASA versions
+	    s/^DATABASE=(.*)$/DATABASE=$1\nMYSQLDB=$1/;      # the renaming wasn't carried out in all PASA scripts, so provide both versions
 	    s/<__MAX_INTRON_LENGTH__>/$maxIntronLen/;
 	    s/<__MIN_PERCENT_ALIGNED__>/0.8/;
 	    s/<__MIN_AVG_PER_ID__>/0.9/;
@@ -400,7 +402,7 @@ sub construct_training_set{
   
 	$cmdString="rm alignAssembly.config; mv temp alignAssembly.config; chmod a+x alignAssembly.config";
 	print "3 $cmdString\n" if ($verbose>=3);
-	system("$cmdString")==0 or die ("failed to execute: $!\n");
+	system("$cmdString")==0 or die ("failed to execute: $cmdString\n");
 	print "3 Adjusted alignAssembly.config\n" if ($verbose>=3); 
     } else {
 	print ("2 Using existing alignAssembly.config.\n") if ($verbose>=3);
@@ -409,30 +411,31 @@ sub construct_training_set{
     # executing the Alignment Assembly
 
     if (!uptodate([$genome_clean, "alignAssembly.config", "transcripts.fasta", "transcripts.fasta.clean"],
-		  ["trainingSetCandidates.gff", "pasa_asmbls_to_training_set.stdout"])){
+		  ["$pasaDBname.assemblies.fasta.transdecoder.genome.gff3", "pasa_asmbls_to_training_set.stdout"])){
 	$cmdString="ln -fs $genome_clean genome.fasta";
 	print "3 $cmdString\n" if ($verbose>=3);
-	system("$cmdString")==0 or die("\nfailed to execute $!\n");
+	system("$cmdString")==0 or die("\nfailed to execute $cmdString\n");
 	
-	my $gmapoption = "";
-	$gmapoption = "--USE_GMAP" if ($useGMAPforPASA);
+	my $gmapoption = "blat";
+	$gmapoption = "gmap" if ($useGMAPforPASA);
 	
 	print "3 Reading MySQL variables from $PASAHOME/pasa_conf/\n" if ($verbose>=3);
-	open(CONFIG, "$PASAHOME/pasa_conf/conf.txt") or die("\nCould not open $PASAHOME/pasa_conf/conf.txt!\n");
+	open(my $config_fh, "<", "$PASAHOME/pasa_conf/conf.txt") or die("\nCould not open $PASAHOME/pasa_conf/conf.txt!\n");
 	my $MYSQLSERVER;
 	my $MYSQL_RO_USER;
 	my $MYSQL_RO_PASSWORD;
 	my $MYSQL_RW_USER;
 	my $MYSQL_RW_PASSWORD;
-	while(<CONFIG>){
-	    $MYSQLSERVER=$1       if /MYSQLSERVER=(.*)/;
-	    $MYSQL_RO_USER=$1     if /MYSQL_RO_USER=(.*)/;
-	    $MYSQL_RO_PASSWORD=$1 if /MYSQL_RO_PASSWORD=(.*)/;
-            $MYSQL_RW_USER=$1      if /MYSQL_RW_USER=(.*)/;
-            $MYSQL_RW_PASSWORD=$1 if /MYSQL_RW_PASSWORD=(.*)/;
+	while(my $line = <$config_fh>){
+	    next if ($line =~ /^\s*#/); # discard comments
+	    $MYSQLSERVER=$1       if ($line =~ /MYSQLSERVER=(.*)/);
+	    $MYSQL_RO_USER=$1     if ($line =~ /MYSQL_RO_USER=(.*)/);
+	    $MYSQL_RO_PASSWORD=$1 if ($line =~ /MYSQL_RO_PASSWORD=(.*)/);
+	    $MYSQL_RW_USER=$1     if ($line =~ /MYSQL_RW_USER=(.*)/);
+	    $MYSQL_RW_PASSWORD=$1 if ($line =~ /MYSQL_RW_PASSWORD=(.*)/);
 	    
 	}
-	close(CONFIG);
+	close($config_fh);
 	print "0 WARNING: MYSQL_RO_PASSWORD is empty!\n" if (! $MYSQL_RO_PASSWORD);
 	
 	my $dbh;
@@ -440,17 +443,21 @@ sub construct_training_set{
 	    &DropDataBase("$MYSQLSERVER","$pasaDBname","$MYSQL_RW_USER","$MYSQL_RW_PASSWORD",\$dbh);
         }
 
-	$perlCmdString="perl $PASAHOME/scripts/Launch_PASA_pipeline.pl -c alignAssembly.config -C -R -g $genome_clean "
-	    ."-t transcripts.fasta.clean -T -u transcripts.fasta $gmapoption 1>Launch_PASA_pipeline.stdout 2>Launch_PASA_pipeline.stderr";
+	if (! -e "$PASAHOME/Launch_PASA_pipeline.pl"){
+	    die("Error: Script Launch_PASA_pipeline.pl not found. Ensure that this script exists in PASAHOME folder: $PASAHOME.\n");
+	}
+	$perlCmdString = "perl $PASAHOME/Launch_PASA_pipeline.pl "
+	    ."-c alignAssembly.config -C -R -g $genome_clean "
+	    ."-t transcripts.fasta.clean -T -u transcripts.fasta --ALIGNERS $gmapoption "
+	    ."1>Launch_PASA_pipeline.stdout 2>Launch_PASA_pipeline.stderr";
 	
 	print "2 Executing the Alignment Assembly: $perlCmdString ..." if ($verbose>=2);
-	print "2 A test output...\n";
 	my $abortString;
 	$abortString = "\nFailed to execute, possible reasons could be:\n";
 	$abortString.= "1. There is already a database named \"$pasaDBname\" in your mysql host.\n";
 	$abortString.= "2. The software \"slclust\" is not installed correctly, try to install it";
 	$abortString.= " again (see the details in the PASA documentation).\n";
-        $abortString.= "3. The fasta headers in cDNA or genome file were not unique.\n";
+	$abortString.= "3. The fasta headers in cDNA or genome file were not unique.\n";
 	$abortString.= "Inspect $trainDir/pasa/Launch_PASA_pipeline.stderr for PASA error messages.\n";
 	
 	system("$perlCmdString")==0 or die ("$abortString");
@@ -458,9 +465,10 @@ sub construct_training_set{
   	
 
         
-
-	$perlCmdString="perl $PASAHOME/scripts/pasa_asmbls_to_training_set.dbi -M \"$pasaDBname:$MYSQLSERVER\" -p "
-	    ."\"$MYSQL_RO_USER:$MYSQL_RO_PASSWORD\" -g $genome_clean 1>pasa_asmbls_to_training_set.stdout 2>pasa_asmbls_to_training_set.stderr";
+	$perlCmdString="perl $PASAHOME/scripts/pasa_asmbls_to_training_set.dbi "
+	    ."--pasa_transcripts_fasta $pasaDBname.assemblies.fasta "
+	    ."--pasa_transcripts_gff3 $pasaDBname.pasa_assemblies.gff3 "
+	    ."1>pasa_asmbls_to_training_set.stdout 2>pasa_asmbls_to_training_set.stderr";
 	
 	print "2 Running $perlCmdString ..." if ($verbose>=2);
 	system("$perlCmdString")==0 or die ("failed to execute: $perlCmdString\n");
@@ -476,38 +484,28 @@ sub construct_training_set{
 			   "output.subclusters.out");
 	foreach my $file (@filesToDelete) {         
 	    $perlCmdString="rm -rf $file";
-	    print "3 Deleting $file" if ($verbose>=3);
+	    print "3 Deleting $file\n" if ($verbose>=3);
 	    system("$perlCmdString");
 	}
     #dropping pasa database 
     &DropDataBase("$MYSQLSERVER","$pasaDBname","$MYSQL_RW_USER","$MYSQL_RW_PASSWORD",\$dbh);
     } else {
- 	print ("2 Skipping PASA training set creation. Using existing trainingSetCandidates.gff.\n") if ($verbose>=2);
+ 	print ("2 Skipping PASA training set creation. Using existing $pasaDBname.assemblies.fasta.transdecoder.genome.gff3.\n") if ($verbose>=2);
     }
     
     # find complete genes in candidate training file
-    if (!uptodate((["trainingSetCandidates.gff"] or ["trainingSetCandidates.gff3"]), ["trainingSetComplete.gff"])){
+    if (!uptodate(["$pasaDBname.assemblies.fasta.transdecoder.genome.gff3"], ["trainingSetComplete.gff"])){
 	print "3 cd ../training\n" if ($verbose>=3);
 	chdir "../training" or die ("Could not change directory to training!\n");
-	# old PASA version (at least before January 2011, probably older) produce different output files than new PASA version:
-	if(-e "../pasa/trainingSetCandidates.fasta"){
-		$cmdString = 'grep complete ../pasa/trainingSetCandidates.fasta | perl -pe \'s/>(\S+).*/$1\$/\'';
-	}else{
-		$cmdString = 'grep complete ../pasa/trainingSetCandidates.cds | perl -pe \'s/>(\S+).*/$1\$/\'';
-	}
+	$cmdString = "grep complete ../pasa/$pasaDBname.assemblies.fasta.transdecoder.cds | perl -pe ".'\'s/>(\S+).*/$1\$/\'';
 	print "3 $cmdString 1> pasa.complete.lst\n" if ($verbose>=3);
-	system("$cmdString 1> pasa.complete.lst")==0 or die("\nfailed to execute $!\n");
+	system("$cmdString 1> pasa.complete.lst")==0 or die("\nfailed to execute $cmdString\n");
 	if (! -e "pasa.complete.lst" || -z "pasa.complete.lst"){
             die ("PASA has not constructed any complete training gene. Training aborted because of insufficient data.\n");
         }
-	# old PASA version (at least before January 2011, probably older) produce different output files than new PASA version:
-	if(-e "../pasa/trainingSetCandidates.gff"){
-		$cmdString="grep -f pasa.complete.lst ../pasa/trainingSetCandidates.gff >trainingSetComplete.temp.gff";
-	}else{
-		$cmdString="grep -f pasa.complete.lst ../pasa/trainingSetCandidates.gff3 >trainingSetComplete.temp.gff";
-	}
+	$cmdString="grep -f pasa.complete.lst ../pasa/$pasaDBname.assemblies.fasta.transdecoder.genome.gff3 >trainingSetComplete.temp.gff";
 	print "2 Running \"$cmdString\" ..." if ($verbose>=2);
-	system("$cmdString")==0 or die("\nfailed to execute $!\n");
+	system("$cmdString")==0 or die("\nfailed to execute $cmdString\n");
 	print " Finished!\n" if ($verbose>=2);
 	
 	# sort trainingSetComplete.temp.gff for gff2gbSmallDNA.pl later
@@ -520,41 +518,39 @@ sub construct_training_set{
 	print " Finished!\n" if ($verbose >=2);
     }
 
-    # calculate the a average gene length
-    if(-e "../pasa/trainingSetCandidates.gff"){
-    	open(FILE, "../pasa/trainingSetCandidates.gff") or die("\nCould not open ../pasa/trainingSetCandidates.gff\n");
-    }else{
-	open(FILE, "../pasa/trainingSetCandidates.gff3") or die("\nCould not open ../pasa/trainingSetCandidates.gff\n");
-    }
+    # calculate the average gene length
+    my $file_fh;
+    open($file_fh, "<", "../pasa/$pasaDBname.assemblies.fasta.transdecoder.genome.gff3") or die("\nCould not open ../pasa/$pasaDBname.assemblies.fasta.transdecoder.genome.gff3\n");
     my $sum=0;
     my $n=0;
-    while(<FILE>){
-	if(/\tgene\t/){
-	    split;
-	    my $len=$_[4]-$_[3]+1;
-	    $sum+=$len;
-	    $n++;
-	}
+    while(my $line = <$file_fh>){
+        if($line =~ /\tgene\t/){
+            my @fields = split(/\t/, $line);
+            my $len=$fields[4]-$fields[3]+1;
+            $sum+=$len;
+            $n++;
+        }
     }
+    close($file_fh);
     print "1 Average gene length in the training set is " . sprintf ("%.2f", ($sum/$n)) . "\n" if ($verbose >=1);
     
     # set flanking DNA
 
-    my $flanking_DNA = int($sum/$n);
+    $flanking_DNA = int($sum/$n);
     $flanking_DNA = 10000 if ($flanking_DNA > 10000);
     $flanking_DNA = 1000 if ($flanking_DNA < 1000);
     print "2 The length of flanking DNA is set as $flanking_DNA accordingly.\n" if ($verbose>=2);
 
     # convert file format from gff to gb
 
-    my $string=find("gff2gbSmallDNA.pl");
+    $string=find("gff2gbSmallDNA.pl");
     print "3 Found script $string.\n" if ($verbose>=3);
     
     $perlCmdString="perl $string trainingSetComplete.gff $genome_clean $flanking_DNA "
     ."trainingSetComplete.gb 1>gff2gbSmallDNA.stdout 2>gff2gbSmallDNA.stderr";
     
     print "3 $perlCmdString\n" if ($verbose>=3);
-    system("$perlCmdString")==0 or die ("failed to execute: $!\n");
+    system("$perlCmdString")==0 or die ("failed to execute: $perlCmdString\n");
     
     # let etraining find prolematic genbank entries
     
@@ -568,16 +564,19 @@ sub construct_training_set{
   
     print "2 Now trying to find out whether the CDS in the training set contain or exclude the stop codon.\n" if ($verbose >=2);
     my $genericPath="$AUGUSTUS_CONFIG_PATH/species/generic";
-    chdir "$genericPath" or die ("Could not change directory to $scriptPath\n");
-    print "3 cd $genericPath\n" if ($verbose>=3);
-
-    $cmdString="cat generic_parameters.cfg | perl -pe 's/(stopCodonExcludedFromCDS )(\s+) /$1true /' > temp_1";
-    system("$cmdString")==0 or die ("failed to execute: $!\n");
+    my $genericPathTrain="$AUGUSTUS_CONFIG_PATH/species/${species}_generic";
+    $cmdString = "cp -r $genericPath $genericPathTrain";
     print "3 $cmdString\n" if ($verbose>=3);
+    system("$cmdString")==0 or die ("failed to execute: $cmdString\n");
+
+    chdir "$genericPathTrain" or die ("Could not change directory to $genericPathTrain\n");
+    print "3 cd $genericPathTrain\n" if ($verbose>=3);
+
+    $cmdString='cat generic_parameters.cfg | perl -pe \'s/(stopCodonExcludedFromCDS ).*/$1true /\' > '."${species}_generic_parameters.cfg";
+    print "3 $cmdString\n" if ($verbose>=3);
+    system("$cmdString")==0 or die ("failed to execute: $cmdString\n");
     
-    system("mv temp_1 generic_parameters.cfg")==0 or die("\nfailed to execute: $!\n");
-    print "3 mv temp_1 generic_parameters.cfg\n" if ($verbose>=3);
-    print "3 Set value of \"stopCodonExcludedFromCDS\" in generic_parameters.cfg to \"true\"\n" if ($verbose>=3);
+    print "3 Set value of \"stopCodonExcludedFromCDS\" in ${species}_generic_parameters.cfg to \"true\"\n" if ($verbose>=3);
     
     # first try with etraining
   #  print "3 mv $trainDir/pasa/trainingSetComplete.gb $trainDir/training/trainingSetComplete.gb\n";   
@@ -585,9 +584,9 @@ sub construct_training_set{
    # system("$cmdString")==0 or die("\nfailed to move trainingSetComplete.gb to $trainDir/training\n");
     print "3 cd $trainDir/training\n" if ($verbose>=3);
     chdir "$trainDir/training" or die ("Could not change directory to $trainDir/training\n");
-    $cmdString="etraining --species=generic trainingSetComplete.gb 1>train.out 2>train.err";
+    $cmdString="etraining --species=${species}_generic trainingSetComplete.gb 1>train.out 2>train.err";
     print "3 Running \"$cmdString\" ... " if ($verbose>=3);
-    system("$cmdString")==0 or die("\nfailed to execute: $!\n");
+    system("$cmdString")==0 or die("\nfailed to execute: $cmdString\n");
     print " Finished!\n" if ($verbose>=3); 
     print "3 train.out and train.err have been made under $trainDir/training.\n" if ($verbose>=3);
     
@@ -597,13 +596,14 @@ sub construct_training_set{
     print "3 Error rate caused by \"exon doesn't end in stop codon\" is $err_rate\n" if ($verbose>=3);
     if($err_rate>=0.5){
 	print "3 The appropriate value for \"stopCodonExcludedFromCDS\" seems to be \"false\".\n" if ($verbose>=3);
-        chdir "$scriptPath" or die ("Can not chdir to $scriptPath.\n");
-        system("cat generic_parameters.cfg | perl -pe 's/(stopCodonExcludedFromCDS )(\s+) /$1false /' > temp_1")==0 or die ("failed to execute: $!\n");
-        system("mv temp_1 generic_parameters.cfg")==0 or die("\nfailed to execute: $!\n");
-        print "3 Setted value of \"stopCodonExcludedFromCDS\" in generic_parameters.cfg to \"false\"\n" if ($verbose>=3);
-        print "3 Try etraining again: etraining --species=$species training.gb.train >train.out ..." if ($verbose>=3);
+        chdir "$genericPathTrain" or die ("Can not chdir to $genericPathTrain.\n");
+        system('cat generic_parameters.cfg | perl -pe \'s/(stopCodonExcludedFromCDS ).*/$1false /\' > '."${species}_generic_parameters.cfg")==0 or die ("failed to execute: $!\n");
+        print "3 Set value of \"stopCodonExcludedFromCDS\" in ${species}_generic_parameters.cfg to \"false\"\n" if ($verbose>=3);
+        print "3 Try etraining again: etraining --species=${species}_generic training.gb.train >train.out ..." if ($verbose>=3);
         chdir "$trainDir/training/" or die ("Can not change directory to $trainDir/training.");
-        system("etraining --species=generic trainingSetComplete.gb 1>train.out 2>train.err")==0 or die("\nfailed to execute: $!\n");
+        $cmdString="etraining --species=${species}_generic trainingSetComplete.gb 1>train.out 2>train.err";
+        print "3 Running \"$cmdString\" ... " if ($verbose>=3);
+        system("$cmdString")==0 or die("\nfailed to execute: $cmdString\n");
         print " Finished!\n" if ($verbose>=3);
         print "3 train.out and train.err have been made again under $trainDir/training.\n" if ($verbose>=3);
 	print "2 Stop codons seem to be contained by CDS. Setting stopCodonExcludedFromCDS to false\n" if ($verbose>=2);
@@ -611,15 +611,20 @@ sub construct_training_set{
     else{
 	print "2 Stop codons seem to be exluded from CDS. Setting stopCodonExcludedFromCDS to true\n" if ($verbose>=2); 
     }
+		
+    $cmdString = "rm -rf $genericPathTrain";
+    print "3 $cmdString\n" if ($verbose>=3);
+    system("$cmdString")==0 or die ("failed to execute: $cmdString\n");
 
     print "1 Now filtering problematic genes from training set...\n" if ($verbose>=1);
 
     # extract badlist
-    print '3 cat train.err | perl -ne \'print \"'."$1".'\n\" if /in sequence (\S+):/\' > badlist' if ($verbose>=3);
-    system("cat train.err | perl -ne 'print \"$1\n\" if /in sequence (\S+):/' > badlist")==0 or die ("failed to execute: $!\n");
+    $perlCmdString='cat train.err | perl -ne \'print "$1\n" if /in sequence (\S+):/\' > badlist';
+    print "3 Running $perlCmdString ...\n" if ($verbose>=3);
+    system("$perlCmdString")==0 or die ("failed to execute: $perlCmdString\n");
 
     # check whether only a small fraction of all entries created a problem, if >10%, output a warning
-    my $bad_num=`wc -l badlist`;
+    my $bad_num=`wc -l < badlist`;
     $bad_num*=1;
     print "3 The number of all entries that created a problem is $bad_num\n" if ($verbose>=3);
     my $frac=$bad_num/$num_TSC;
@@ -648,7 +653,8 @@ sub prepare_genome{
     $perlCmdString="perl $string $rootDir/seq/genome_clean.fa > genome.summary";
     print "3 Running $perlCmdString ..." if ($verbose>=3);
     system("$perlCmdString")==0 or die("\nfailed to execute: $perlCmdString!\n");
-    
+    print " Finished!\n" if ($verbose>=3);
+
     # create contigs gbrowse file
     $cmdString='cat genome.summary | grep "bases." | perl -pe \'s/(\d+)\sbases.\s+(\S*) BASE.*/$2\tassembly\tcontig\t1\t$1\t.\t.\t.\tContig $2/\' > contigs.gff';
     print "3 Running $cmdString ..." if ($verbose>=3);
@@ -699,7 +705,7 @@ sub alignments_and_hints{
 	system("ln -s cdna.psl cdna.f.psl");
     }
     # create gbrowse files
-    my $string=find("blat2gbrowse.pl");
+    $string=find("blat2gbrowse.pl");
     print "3 Found script $string.\n" if ($verbose>=3);
     $perlCmdString="perl $string --source=CDNA cdna.f.psl cdna.gbrowse";
     print "3 Running $perlCmdString ..." if ($verbose>3);
@@ -707,7 +713,7 @@ sub alignments_and_hints{
     print " Finished!\n" if ($verbose>3);
     
     # create hints
-    print "1 Creating hints from cDNA alignments....\n" if ($verbose>=1);
+    print "1 Creating hints from cDNA alignments ...\n" if ($verbose>=1);
     chdir "../hints" or die("\nCould not change directory to ../hints\n");
     $string=find("blat2hints.pl");
     $perlCmdString="perl $string --in=../cdna/cdna.f.psl --out=hints.E.gff --minintronlen=35 --trunkSS 1>blat2hints.stdout 2>blat2hints.stderr";
@@ -753,7 +759,7 @@ sub autoTrain_no_utr{
     # run autoAugTrain.pl
     $perlCmdString="perl $scriptPath/autoAugTrain.pl -t=$trainingset -s=$species $useexistingopt -g=$genome_clean -w=$rootDir $verboseString --opt=$optrounds";
     print "\n2 $perlCmdString\n" if ($verbose>=2);
-    system("$perlCmdString")==0 or die ("failed to execute: $!\n");
+    system("$perlCmdString")==0 or die ("failed to execute: $perlCmdString\n");
 
     print "\n1 ####### Finished step 1 at " .(scalar localtime()) . 
 	". All files are stored in $rootDir/autoAugTrain #######\n" if ($verbose>=1);
@@ -782,15 +788,17 @@ sub autoAug_prepareScripts{
     $autoAugDir = $autoAugDir_hints_utr if ($hints_switch && $utr_switch);
     $autoAugDir = $autoAugDir_utr       if (!$hints_switch && $utr_switch);
 
-    my $hintsString ="--hints=$hints" if ($hints_switch);
-    my $utrString   ="--utr"          if ($utr_switch);
+    my $hintsString = "";
+    my $utrString  = "";
+    $hintsString = "--hints=$hints" if ($hints_switch);
+    $utrString   = "--utr"          if ($utr_switch);
    
     
     $perlCmdString = "perl $scriptPath/autoAugPred.pl -g=$genome_clean --species=$species -w=$rootDir $utrString " . 
 	"$verboseString $hintsString $useexistingopt";
     $perlCmdString .= " --singleCPU" if ($singleCPU);
-    print "2 $perlCmdString" if ($verbose>=2);
-    system("$perlCmdString")==0 or die("\nfailed to execute $!\n");
+    print "2 $perlCmdString\n" if ($verbose>=2);
+    system("$perlCmdString")==0 or die("\nfailed to execute $perlCmdString\n");
     
     my $stepNum;
     $stepNum=2 if (!$hints_switch && !$utr_switch);
@@ -832,8 +840,10 @@ sub autoAug_continue{
         print "\n";
     }
 
-    my $hintsString="--hints=$hints" if ($hints_switch);
-    my $utrString=" --utr" if ($utr_switch);
+    my $hintsString = "";
+    my $utrString = "";
+    $hintsString = "--hints=$hints" if ($hints_switch);
+    $utrString = " --utr" if ($utr_switch);
 
     $estali="$rootDir/cdna/cdna.f.psl" if ($pasa);
 
@@ -842,7 +852,7 @@ sub autoAug_continue{
     $mainDir = "$autoAugDir_hints"     if ($index==2);
     $mainDir = "$autoAugDir_utr"       if ($index==3);
  
-    my $shellDir = "$mainDir/shells";
+    $shellDir = "$mainDir/shells";
 
 
     $perlCmdString = "perl $scriptPath/autoAugPred.pl --species=$species --genome=$rootDir/seq/genome_clean.fa --continue --workingdir=$rootDir $verboseString $hintsString $utrString $useexistingopt";
@@ -868,7 +878,7 @@ sub autoAug_continue{
 
 
 
-       ################## run AUGUGUS completely automatically ##################
+       ################## run AUGUSTUS completely automatically ##################
 
 
 sub autoAug_noninteractive{
@@ -876,8 +886,10 @@ sub autoAug_noninteractive{
     my $hints_switch=shift;       # for AUGUSTUS with hints
     my $utr_switch=shift;         # for AUGUSTUS with UTR
 
-    my $hintsString="--hints=$hints" if ($hints_switch);
-    my $utrString="--utr"            if ($utr_switch);
+    my $hintsString="";
+    my $utrString="";
+    $hintsString="--hints=$hints" if ($hints_switch);
+    $utrString="--utr"            if ($utr_switch);
 
     my $string;
     $string="ab initio (without hints and utr)" if(!$hints_switch && !$utr_switch);
@@ -918,7 +930,7 @@ sub autoTrain_with_utr{
   	  $perlCmdString="perl $scriptPath/autoAugTrain.pl -g=$genome_clean -s=$species --utr -e=$estali $augString -w=$rootDir $verboseString --opt=$optrounds $useexistingopt";
     }
     print "\n2 $perlCmdString\n" if ($verbose>=2);
-    system("$perlCmdString")==0 or die ("failed to execute: $!\n");
+    system("$perlCmdString")==0 or die ("failed to execute: $perlCmdString\n");
 
     print "\n1 ####### Finished step $stepNum, all files are stored in $rootDir/training/utr #######\n" if ($verbose>=1);
     
@@ -948,7 +960,7 @@ sub collect{
 
     chdir "$summary_dir" or die("\nError: cannot change directory to $summary_dir!\n");
     for(("gbrowse", "hints","predictions","seq", "genes", "config")){mkdir "$_"}
-    print "3 All necessary diretories have been created unter $summary_dir.\n" if ($verbose>=3);
+    print "3 All necessary directories have been created under $summary_dir.\n" if ($verbose>=3);
     
     # collect gbrowse files
     print "3 cd gbrowse\n" if ($verbose>=3);
@@ -957,14 +969,14 @@ sub collect{
 
 
     $cmdString = "cp $rootDir/seq/contigs.gff contigs.gff";
-    system("$cmdString")==0 or die("\nfailed to execute: $!\n");
+    system("$cmdString")==0 or die("\nfailed to execute: $cmdString\n");
 
     if (-f "$rootDir/cdna/cdna.gbrowse"){
 	$cmdString = "ln -sf $rootDir/cdna/cdna.gbrowse cdna.gbrowse";
 	system("$cmdString")==0 or die("\nfailed to execute: $cmdString\n");
     }
     
-    if (-f $fasta_cdna){
+    if (defined($fasta_cdna) && -f $fasta_cdna){
 	$cmdString = "ln -sf $fasta_cdna cdna.fa";
 	system("$cmdString")==0 or die("\nfailed to execute: $cmdString\n");
     }
@@ -986,11 +998,11 @@ sub collect{
     chdir "../hints";
     if($pasa){
 	$cmdString="ln -sf $rootDir/hints/hints.E.gff hints.E.gff";
-	system("$cmdString")==0 or die("\nfailed to execute: $!\n");
+	system("$cmdString")==0 or die("\nfailed to execute: $cmdString\n");
         print "3 $cmdString\n" if ($verbose>=3);
     } elsif ($havehints) {
 	$cmdString="ln -sf  $hints hints.E.gff";
-	system("$cmdString")==0 or die("\nfailed to execute: $!\n");
+	system("$cmdString")==0 or die("\nfailed to execute: $cmdString\n");
 	print "3 $cmdString\n" if ($verbose>=3);
     }
     
@@ -1015,7 +1027,7 @@ sub collect{
     chdir "../seq";
     $cmdString="ln -s $genome genome.fa" if (!uptodate([$genome], ["genome.fa"]));
 
-    system("$cmdString")==0 or die("\nfailed to execute: $!\n");
+    system("$cmdString")==0 or die("\nfailed to execute: $cmdString\n");
     print "3 $cmdString\n" if ($verbose>=3);
     
     # collect config files
@@ -1043,12 +1055,12 @@ sub collect{
 	$i =~ /^(\/.*\/)(.*)\n$/;
 	if(-f "$2"){
 	    $cmdString="ln -fs $1$2 $2"."_another";
-	    system("$cmdString")==0 or die("\nfailed to execute: $!\n");
+	    system("$cmdString")==0 or die("\nfailed to execute: $cmdString\n");
 	    print "3 $cmdString\n" if ($verbose>=3);
 	}
 	else{
 	    $cmdString="ln -s $1$2 $2";
-	    system("$cmdString")==0 or die("\nfailed to execute: $!\n");
+	    system("$cmdString")==0 or die("\nfailed to execute: $cmdString\n");
             print "3 $cmdString\n" if ($verbose>=3);
 	}
     }
@@ -1069,14 +1081,9 @@ sub check_upfront{
     die("Error: The environment variable AUGUSTUS_CONFIG_PATH is not defined.\n") unless $ENV{'AUGUSTUS_CONFIG_PATH'};
     die("Error: The environment variable PASAHOME is undefined.\n") if ($pasa && !defined($ENV{'PASAHOME'}));
     
-    my $augpath = "$ENV{'AUGUSTUS_CONFIG_PATH'}/../bin/augustus";
-    if (system("$augpath > /dev/null 2> /dev/null") != 0){
-	if (! -f $augpath){
-	    print STDERR "Error: augustus executable not found at $augpath.\n";
-	} else {
-	    print STDERR "Error: $augpath not executable on this machine.\n";
-	}
-	exit (1);
+    if (system("which augustus > /dev/null") != 0){
+        print STDERR "Error: augustus not installed. Please install first.\n";
+        exit (1);
     }
     if (defined($fasta_cdna)){
 	if (system("which blat > /dev/null") != 0){
@@ -1090,6 +1097,12 @@ sub check_upfront{
 	    exit(1);
 	}
     }
+    if ($pasa){
+        if (system("which seqclean > /dev/null") != 0){
+            print STDERR "Error: seqclean script not installed. Install seqclean first or if it is available in a PASAHOME subdirectory add this to PATH.\n";
+            exit(1);
+        }
+    }
     find("gff2gbSmallDNA.pl");
     find("summarizeACGTcontent.pl");
     print "ok.\n" if ($verbose>=2);
@@ -1107,19 +1120,19 @@ sub check_fasta_headers{
 	chomp;
 	if($_=~m/\s/){
 	    if($spaces == 0){
-		print "1 - WARNING: Detected whitespace in fasta header of file $fastaFile. ".$stdStr;
+		print "1 - WARNING: Detected whitespace in fasta header of file $fastaFile. ".$stdStr."\n";
 		$spaces++;
 	    }
 	}
 	if($_=~m/\|/){
 	    if($orSign == 0){
-		print "1 - WARNING: Detected | in fasta header of file $fastaFile. ".$stdStr;
+		print "1 - WARNING: Detected | in fasta header of file $fastaFile. ".$stdStr."\n";
 		$orSign++;
 	    }
 	}
 	if($_=!m/[>a-zA-Z0123456789]/){
 	    if($someThingWrongWithHeader==0){
-		print "1 - WARNING: Fasta headers inf file $fastaFile seem to contain non-letter and non-number characters. That means they may contain some kind of special character. ".$stdStr;
+		print "1 - WARNING: Fasta headers inf file $fastaFile seem to contain non-letter and non-number characters. That means they may contain some kind of special character. ".$stdStr."\n";
 		$someThingWrongWithHeader++;
 	    }
 	}
