@@ -1,19 +1,10 @@
-
-/**********************************************************************
- * file: compgenepred.cc licence: Artistic Licence, see file
- * LICENCE.TXT or
- * http://www.opensource.org/licenses/artistic-license.php descr.:
- * comparative gene prediction on multiple species authors: Mario
- * Stanke, Alexander Gebauer, Stefanie Koenig
+/*
+ * compgenepred.cc
  *
- * date    |   author       |  changes
- * --------|----------------|------------------------------------------
- * 07.03.12| Mario Stanke   | creation of the file
- * 06.10.12|Stefanie Koenig | construction of an OrthoGraph from a set of
- *         |                | orthologous sequences + integration of
- *         |                | the optimization method
- ***********************************************************************/
-
+ * License: Artistic License, see file LICENSE.TXT or 
+ *          https://opensource.org/licenses/artistic-license-1.0
+ */
+  
 #include "compgenepred.hh"
 #include "orthograph.hh"
 #include "mea.hh"
@@ -213,7 +204,7 @@ void CompGenePred::start(){
 		throw ProjectError("Is not numeric.");
 	    dd_factors.push_back(pos);
 	}
-    } catch (ProjectError e) {
+    } catch (ProjectError &e) {
 	throw ProjectError("Format error parsing parameter --/CompPred/dd_factor=" + dd_param_s +".\n" + e.getMessage());
     }
     bool onlySampling = false;
@@ -230,7 +221,7 @@ void CompGenePred::start(){
 	}else{
 	  cout << "# No outfile for logReg parameters specified. Writing parameters to " << Constant::configPath <<  "/cgp/log_reg_parameters_trained.cfg" << endl;
 	}
-      } catch (ProjectError e) {
+      } catch (ProjectError &e) {
 	throw ProjectError("For parameter training a reference species must be specified. Use --refSpecies=<SPECIES> and note, that <SPECIES> must be identical to one of the species names provided in the alignment and tree files.");
       }
     }
@@ -479,13 +470,19 @@ void CompGenePred::start(){
 
 	// create additional ECs for each species and  insert them into exoncands and alignedECs
 	vector<map<int_fast64_t,ExonCandidate*> > addECs(speciesNames.size()); // new ECs that need to be mapped to the alignment
-        for (int s = 0; s < speciesNames.size(); s++) {
+	for (int s = 0; s < speciesNames.size(); s++) {
 	    if (seqRanges[s]) {
-		AnnoSequence *as = seqRanges[s];		
-		// this is needed for IntronModel::dssProb in GenomicMSA::createExoncands
-		namgene.getPrepareModels(as->sequence, as->length); 
-		// identifies exon candidates in the sequence for species s
-		geneRange->createExonCands(s, as->sequence, exoncands[s], addECs[s]);
+	        AnnoSequence *as = seqRanges[s];
+	        try {
+	            // this is needed for IntronModel::dssProb in GenomicMSA::createExoncands
+	            namgene.getPrepareModels(as->sequence, as->length);
+	            // identifies exon candidates in the sequence for species s
+	            geneRange->createExonCands(s, as->sequence, exoncands[s], addECs[s]);
+	        } catch (ProjectError &e) {
+		    cerr << "CGP error when creating additional ECs for " << speciesNames[s] << endl
+			 << e.getMessage();
+		    throw e;
+	        }
 	    }
 	}
 
@@ -539,7 +536,7 @@ void CompGenePred::start(){
        
 	if(use_omega){
 	    geneRange->computeOmegasEff(hects, seqRanges, &ctree, &codonAli); // omega and number of substitutions is stored as OrthoExon attribute
-	    // calculates an omega for every single codon alignment and prints wiggle trac for ever reding frame and species combination that exists in an ortho exon
+	    // calculates an omega for every single codon alignment and prints wiggle trac for ever reading frame and species combination that exists in an ortho exon
 	    //geneRange->printOmegaForCodon(outdir);
 	    //inefficient omega calculation, only use for debugging purpose 
 	    //geneRange->computeOmegas(hects, seqRanges, &ctree);
@@ -602,7 +599,7 @@ void CompGenePred::start(){
     GeneMSA::topologies.clear(); 
   
     if(Properties::hasProperty("referenceFile")){
-      // initialise training of log reg parameters
+      // initialize training of log reg parameters
       train_OEscore_params(speciesNames.size());
     }
   } 
