@@ -1,26 +1,9 @@
-/**********************************************************************
- * file:    exonmodel.cc
- * licence: Artistic Licence, see file LICENCE.TXT or 
- *          http://www.opensource.org/licenses/artistic-license.php
- * descr.:  coding exons only, UTR exons are modelled in utrmodel.cc
- * authors: Mario Stanke, mario@gobics.de
+/*
+ * exonmodel.cc
  *
- * date    |   author      |  changes
- * --------|---------------|------------------------------------------
- * 06.05.02| Mario Stanke  | debugging and testing
- * 18.05.02| Mario Stanke  | added length distributions
- * 31.05.02| Mario Stanke  | implementation of viterbi algorithm
- * 06.10.02| Mario Stanke  | making length distr independent of content
- * 18.11.02| Mario Stanke  | internal exon terminal emission part
- * 30.12.02| Mario Stanke  | moving splice site models to intron
- * 25.03.03| Mario Stanke  | shadow exons on reverse strand
- * 02.07.04| Mario Stanke  | malus for all exons, not only for those without a bonus
- * 19.08.04| Mario Stanke  | corrected rare bug with exon state at end of dna
- * 23.12.04| Mario Stanke  | bug fixed: wrong reading frame in call to getExonListInRange
- * 08.02.05| Mario Stanke  | bug fixed: exon hints were missed for reverse terminal or reverse single exons.
- * 22.08.05| Mario Stanke  | training on genes with incomplete 3' end, incomplete exon not used for lendist
- * 09.09.08| Mario Stanke  | introduce fuzzyness in dss and ass hints
- **********************************************************************/
+ * License: Artistic License, see file LICENSE.TXT or 
+ *          https://opensource.org/licenses/artistic-license-1.0
+ */
 
 #include "exonmodel.hh"
 
@@ -35,11 +18,11 @@
 #include <fstream>
 
 /*
- * Initialisation of static data members
+ * Initialization of static data members
  */
 
 vector<Integer> ExonModel::patterncount[3];      // {0,1,2}x{acgt}^(k+1), the reading frame is 
-                                                 // the positiion of the emitted (last) nucleotide
+                                                 // the position of the emitted (last) nucleotide
 vector<Integer> ExonModel::initpatterncount[3];
 vector<Integer> ExonModel::etpatterncount[3];
 Integer ExonModel::k = 4;
@@ -81,7 +64,7 @@ Boolean ExonModel::hasLenDist = false;
 //Boolean ExonModel::hasAAdep = false;      // not in use right now
 Integer ExonModel::gesbasen[3]  = { 0, 0, 0 };
 Double  ExonModel::patpseudo = 1;         // pseudocount for patterns in sequence
-Integer ExonModel::exonLenD = 4000;       // use detailled length distribution up to this number
+Integer ExonModel::exonLenD = 4000;       // use detailed length distribution up to this number
 Integer ExonModel::minPatSum = 0;         // for the decision to shorten the emission pattern
 vector<Integer> ExonModel::lenCountSingle;   // length count of Single exons (length of biol. exon)
 vector<Integer> ExonModel::lenCountInitial;  // length count of Initial exons (length of biol. exon)
@@ -118,6 +101,10 @@ double          ExonModel::lenboostE = 0; // lengths above L are improved, the m
 OpenReadingFrame::OpenReadingFrame(const char *dna, int _max_exon_length, int _n) :
     n(_n), max_exon_length(_max_exon_length)
 {
+    if (*dna != tolower(*dna))
+	throw ProjectError("Internal Error: upper case in DNA "
+			   + string(dna).substr(0, 50) + "...");
+
     nearestStopForward.resize(n);
     nearestStopReverse.resize(n);
     int stopcodpos, i;
@@ -215,8 +202,6 @@ int OpenReadingFrame::leftmostExonBegin(int frame, int base, bool forward){
  */
 
 bool OpenReadingFrame::isStopcodon( const char* dna ){
-    if (*dna != tolower(*dna))
-	throw ProjectError("Internal Error: upper case dna"); // TEMP: just for now
     // Oliver, 2009/06/24: commented this out to give translation table priority
     // over {ochre,amber,opal}prob values; this basically causes
     // stopcodons with prob=0 to appear neither prematurely nor as stopcodons
@@ -297,13 +282,13 @@ int ExonModel::getInnerPartEndOffset(StateType type){
  * destructor
  */
 ExonModel::~ExonModel( ){
-    // TODO: delete what is neccessary
+    // TODO: delete what is necessary
     if( --exoncount == 0 )
 	lastParIndex = -1;
 }
 
 /*
- * ===[ ExonModel initialisation of class variables ]======================
+ * ===[ ExonModel initialization of class variables ]======================
  */
 void ExonModel::init() {
     /*
@@ -315,62 +300,62 @@ void ExonModel::init() {
     minwindowcount=3;           // see class Smooth in commontrain.hh	
     try{
 	verbosity = Properties::getIntProperty("/ExonModel/verbosity");
-    }catch( ProjectError e) {    
+    }catch( ProjectError &e) {
 	cerr << e.getMessage();
     }
     try{
 	k = Properties::getIntProperty( "/ExonModel/k" );
-    }catch( ProjectError e) {    
+    }catch( ProjectError &e) {    
 	cerr << e.getMessage();
     }
     try{
 	patpseudo = Properties::getDoubleProperty( "/ExonModel/patpseudocount" );
-    }catch( ProjectError e) { 
+    }catch( ProjectError &e) { 
 	cerr << e.getMessage();
     }
     try{
 	exonLenD = Properties::getIntProperty( "/ExonModel/exonlengthD" );
-    }catch( ProjectError e) { 
+    }catch( ProjectError &e) { 
 	cerr << e.getMessage();
     }
     try{
 	slope_of_bandwidth = Properties::getdoubleProperty( "/ExonModel/slope_of_bandwidth");
-    }catch( ProjectError e) { 
+    }catch( ProjectError &e) { 
 	cerr << e.getMessage();
     }
     try{
 	minwindowcount = Properties::getIntProperty( "/ExonModel/minwindowcount");
-    }catch( ProjectError e) { 
+    }catch( ProjectError &e) { 
 	cerr << e.getMessage();
     }
     try{
 	min_exon_length = Properties::getIntProperty( "/ExonModel/minexonlength");
-    } catch( ProjectError e) { 
+    } catch( ProjectError &e) { 
 	// optional parameter
     }
     try{
 	minPatSum = Properties::getIntProperty( "/ExonModel/minPatSum");
-    } catch( ProjectError e) { 
+    } catch( ProjectError &e) { 
 	cerr << e.getMessage();
     }
     try{
 	etorder = Properties::getIntProperty( "/ExonModel/etorder");
-    } catch( ProjectError e) { 
+    } catch( ProjectError &e) { 
 	cerr << e.getMessage();
     }
     try{
 	etpseudocount = Properties::getIntProperty( "/ExonModel/etpseudocount");
-    } catch( ProjectError e) { 
+    } catch( ProjectError &e) { 
 	cerr << e.getMessage();
     }
     try{
 	tis_motif_memory = Properties::getIntProperty( "/ExonModel/tis_motif_memory");
-    } catch( ProjectError e) { 
+    } catch( ProjectError &e) { 
 	cerr << e.getMessage();
     }
     try{
 	tis_motif_radius = Properties::getIntProperty( "/ExonModel/tis_motif_radius");
-    } catch( ProjectError e) { 
+    } catch( ProjectError &e) { 
 	cerr << e.getMessage();
     }
     try{
@@ -379,10 +364,10 @@ void ExonModel::init() {
 	    cout << "Warning: /ExonModel/lenboostE < 0 does not make sense. Will use 0 instead." << endl;
 	    lenboostE = 0.0;
 	}
-    } catch( ProjectError e) {}
+    } catch( ProjectError &e) {}
     try{
 	lenboostL = Properties::getIntProperty( "/ExonModel/lenboostL");
-    } catch( ProjectError e) {}
+    } catch( ProjectError &e) {}
 	
     trans_init_window = Constant::trans_init_window;
 
@@ -1020,7 +1005,7 @@ void ExonModel::viterbiForwardAndSampling(ViterbiMatrixType& viterbi, // matrix
 		     << endl;
 #endif
 #endif		    
-	    // if it's a terminal or rinitial exon, we backtrack from igenic which is
+	    // if it's a terminal or initial exon, we backtrack from igenic which is
 	    // unaware of substates, so the given state won't refer to a substate; 
 	    // in order to find out, we check viterbi: if the probability comes from the
 	    // profile, there will be substates, otherwise not
@@ -1126,7 +1111,7 @@ void ExonModel::viterbiForwardAndSampling(ViterbiMatrixType& viterbi, // matrix
 				oli.resetPredEnd();
 				oli.state = getFullStateId(predState, exonScorer->getPredSubstate());
 			    }
-			} catch(NoSubmapFoundError e) {}
+			} catch(NoSubmapFoundError &e) {}
 		} 
 		Double predProb = predVit.get(predState) * transEmiProb;
 		if (predProb > maxProb) {
@@ -1153,7 +1138,7 @@ void ExonModel::viterbiForwardAndSampling(ViterbiMatrixType& viterbi, // matrix
 	    optionslist->prepareSampling();
 	    try {
 		oli = optionslist->sample();
-	    } catch (ProjectError e) {
+	    } catch (ProjectError &e) {
 		cerr << "Sampling error in exon model. state=" << state << " base=" << base << endl;
 		throw e;
 	    }
@@ -1420,7 +1405,7 @@ Double ExonModel::endPartEmiProb(int end) const {
 /*
  * ===[ ExonModel::notEndPartEmiProb ]=====================================
  *
- * Probability of the emission of the exon exluding the fixed length end part.
+ * Probability of the emission of the exon excluding the fixed length end part.
  * This includes 
  * - the beginPart     (translation initiation, ass or reverse dss)
  * - the startSeq part (first k or less emissions after the begin part)
@@ -1585,7 +1570,7 @@ Double ExonModel::notEndPartEmiProb(int beginOfStart, int right, int frameOfRigh
 	    else
 		restSeqProb = Pls[right-beginOfStart][mod3(frameOfRight + right - beginOfStart)]
 		    [s2i.rc(sequence + beginOfStart)];		
-	} catch (InvalidNucleotideError e) {
+	} catch (InvalidNucleotideError &e) {
 	    // we dont assume anything in this case, take iid uniform distribution on {a,c,g,t}
 	    restSeqProb = pow(Constant::probNinCoding, right-beginOfStart + 1); // 0.25
 	}
@@ -1598,7 +1583,7 @@ Double ExonModel::notEndPartEmiProb(int beginOfStart, int right, int frameOfRigh
 	 * inner sequence part from endOfStart+1 to right
 	 * | initial pattern | initial content model| exon content model| exon terminating model (dss)|
 	 * Depending on the exon type, some of the models may not apply
-	 * For short exons the precedence is inital -> terminal -> inner
+	 * For short exons the precedence is initial -> terminal -> inner
 	 * but terminal applies only completely or not at all.
 	 */
 	int endOfInitial, beginOfTerm,  endOfStart; // forward
@@ -1615,7 +1600,7 @@ Double ExonModel::notEndPartEmiProb(int beginOfStart, int right, int frameOfRigh
 		else                  // init pattern at right side
 		    restSeqProb = Pls[k-1][mod3(frameOfRight+right-beginOfInitP)]
 			[Seq2Int(k).rc(sequence + beginOfInitP)];
-	} catch (InvalidNucleotideError e) {
+	} catch (InvalidNucleotideError &e) {
 	    restSeqProb = pow(Constant::probNinCoding, (int) k ); // 0.25
 	}
 
@@ -1946,7 +1931,7 @@ Double ExonModel::seqProb(int left, int right, int frameOfRight) const {
 
     bool reverse = !isOnFStrand(etype);
     Seq2Int s2i(k+1);
-    if (left < 0) {   // new initialisation
+    if (left < 0) {   // new initialization
 	seqProb = 1;
         oldleft = oldright = oldframe = -1;
         oldtype = TYPE_UNKNOWN;
@@ -1961,7 +1946,7 @@ Double ExonModel::seqProb(int left, int right, int frameOfRight) const {
 		int f = reverse? mod3(frameOfRight+right-curpos) : mod3(frameOfRight-right+curpos);
 		int pn = reverse? s2i.rc(sequence+curpos) : s2i(sequence+curpos-k);
 		seqProb *= emiprobs.probs[f][pn];
-            } catch (InvalidNucleotideError e) {
+            } catch (InvalidNucleotideError &e) {
                 seqProb *= Constant::probNinCoding; //  0.25, 1/4
             }
         }
@@ -1978,7 +1963,7 @@ Double ExonModel::seqProb(int left, int right, int frameOfRight) const {
 	    seqProb  *= emiprobs.probs[f][pn];
 	    if (inCRFTraining && (countEnd < 0 || (curpos >= countStart && curpos <= countEnd)))
 		GCemiprobs[gcIdx].addCount(GCemiprobs[gcIdx].getIndex(f,pn));
-	} catch (InvalidNucleotideError e) {
+	} catch (InvalidNucleotideError &e) {
 	    seqProb  *= Constant::probNinCoding; // 0.25 1/4
 	}
     }
@@ -2016,7 +2001,7 @@ Double ExonModel::eTermSeqProb(int left, int right, int frameOfRight) const {
 		int f = reverse? mod3(frameOfRight+right-curpos) : mod3(frameOfRight-right+curpos);
 		int pn = reverse? s2i.rc(sequence+curpos) : s2i(sequence+curpos-k);
 		seqProb *= etemiprobs[f][pn];
-	    } catch (InvalidNucleotideError e) {
+	    } catch (InvalidNucleotideError &e) {
 		seqProb *= Constant::probNinCoding; // 0.25, 1/4
 	    }
 	}
@@ -2043,7 +2028,7 @@ Double ExonModel::initialSeqProb(int left, int right, int frameOfRight) const {
 	    int f = reverse? mod3(frameOfRight+right-curpos) : mod3(frameOfRight-right+curpos);
 	    int pn = reverse? s2i.rc(sequence+curpos) : s2i(sequence+curpos-k);
 	    seqProb *= initemiprobs[f][pn];
-	} catch (InvalidNucleotideError e) {
+	} catch (InvalidNucleotideError &e) {
 	    seqProb *= Constant::probNinCoding; // 0.25, 1/4
 	}
     }
