@@ -1,16 +1,11 @@
-/**********************************************************************
- * file:    genbank.cc
- * licence: Artistic Licence, see file LICENCE.TXT or 
- *          http://www.opensource.org/licenses/artistic-license.php
- * descr.:  sequence and gene struture input from file
- * authors: Mario Stanke, mario@gobics.de, Stafilarakis
+/*
+ * genbank.cc
  *
- * date     |   author      |  changes
- * ---------|---------------|------------------------------------------
- * 03.01.07 | Mario Stanke  | fixed bug with clength (was 3 too long for every exon except the last)
- * 05.04.07 | Mario Stanke  | Do not read out incomplete mRNA if it does not have a 
- *          |               | matching but an overlapping CDS. Usefull for training with 3'incompete genes.
- **********************************************************************/
+ * License: Artistic License, see file LICENSE.TXT or 
+ *          https://opensource.org/licenses/artistic-license-1.0
+ * 
+ * Description: sequence and gene struture input from file
+ */
 
 #include "genbank.hh"
 #include "fasta.hh"
@@ -48,14 +43,14 @@ AnnoSequence* GBProcessor::getAnnoSequence( GBPositions* pos ){
     bool stopCodonExcludedFromCDS = false;
     try {
 	stopCodonExcludedFromCDS = Properties::getBoolProperty("stopCodonExcludedFromCDS");
-    } catch (ProjectError e) {
+    } catch (ProjectError &e) {
 	stopCodonExcludedFromCDS = false;
     }
     bool withUTR;
     try {
       string utr = Properties::getProperty("UTR");
       withUTR = (utr == "both" || utr == "1" || utr == "on" || utr == "5");
-    } catch (ProjectError e) {
+    } catch (ProjectError &e) {
       withUTR = false;
     }
 
@@ -309,7 +304,7 @@ AnnoSequence* GBProcessor::getAnnoSequenceList(){
 		last = annoseq;
 		annocount++;
 	    }
-	} catch (GBError e) {
+	} catch (GBError &e) {
 	  cerr << "GBProcessor::getGeneList(): " << e.getMessage() << endl;
 	  cerr << "Encountered error after reading " << annocount << " annotations." << endl;
  	}
@@ -487,7 +482,7 @@ GBFeature::GBFeature(const char *pos){
       }    
       exon_old = exon;
     }
-  } catch (ProjectError e) {
+  } catch (ProjectError &e) {
     cerr << "Constructing GenBank feature: " << e.getMessage() << endl;
     throw GBError("GBFeature constructor:Format error when reading genbank format.");
   }
