@@ -1,18 +1,9 @@
-/**********************************************************************
- * file:    properties.cc
- * licence: Artistic Licence, see file LICENCE.TXT or
- *          http://www.opensource.org/licenses/artistic-license.php
- * descr.:
- * authors: Stafilarakis, Mario Stanke (mario@gobics.de)
+/*
+ * properties.cc
  *
- * date    |   author      |  changes
- * --------|---------------|------------------------------------------
- * 26.09.01| Stafilarakis  | creations of the class
- * 04.08.03| Stanke        | changed operator Boolean( )
- * 01.08.05| Stanke        | added new species
- * 13.08.05| Mario Stanke  | code species independent: species is prefix of config file name
- * 04.04.07| Mario Stanke  | added parameters
- **********************************************************************/
+ * License: Artistic License, see file LICENSE.TXT or 
+ *          https://opensource.org/licenses/artistic-license-1.0
+ */
 
 #include "properties.hh"
 
@@ -421,7 +412,7 @@ void Properties::init( int argc, char* argv[] ){
 	}
     }
     if (configPath[configPath.size()-1] != '/')
-	configPath += '/';  // append slash if neccessary
+	configPath += '/';  // append slash if necessary
 
     // does the directory actually exist?
     struct stat buffer;
@@ -440,7 +431,7 @@ void Properties::init( int argc, char* argv[] ){
 	optCfgFile = expandHome(configPath + "cgp/log_reg_parameters_default.cfg");
 	try {
 	    readFile(optCfgFile);
-	} catch (PropertiesError e){
+	} catch (PropertiesError &e){
 	    throw ProjectError("Default configuration file with parameters from logistic regression " + optCfgFile + " not found!");
 	}
     }
@@ -465,7 +456,7 @@ void Properties::init( int argc, char* argv[] ){
     speciesDir = SPECIES_SUBDIR + speciesValue + "/";
     try {
 	readFile(configPath + speciesDir + speciesParFileName);
-    } catch (PropertiesError e){
+    } catch (PropertiesError &e){
 	throw ProjectError("Species-specific configuration files not found in " + configPath + SPECIES_SUBDIR + ". Type \"augustus --species=help\" to see available species.");
     }
 
