@@ -1,16 +1,11 @@
-/**********************************************************************
- * file:    randseqaccess.cc
- * licence: Artistic Licence, see file LICENCE.TXT or 
- *          http://www.opensource.org/licenses/artistic-license.php
- * descr.:  random acces to sequence data, e.g. get me chr1:1000-2000 from species 'human'
- * authors: Mario Stanke
+/*
+ * randseqaccess.cc
  *
- * date    |   author      |  changes
- * --------|---------------|------------------------------------------
- * 07.03.12| Mario Stanke  | creation of the file
- * 21.03.12| Stefanie König| implementation of MemSeqAcess functions
- * 09.06.12| yuqiulin      | mysql access to sequences
- **********************************************************************/
+ * License: Artistic License, see file LICENSE.TXT or 
+ *          https://opensource.org/licenses/artistic-license-1.0
+ * 
+ * Description: random acces to sequence data, e.g. get me chr1:1000-2000 from species 'human'
+ */
 
 #include "randseqaccess.hh"
 #include "genbank.hh"
@@ -95,7 +90,7 @@ void SpeciesCollection::readExtrinsicCFGFile(vector<string> &speciesNames){
 				    try{
 					addSpeciesToGroup(speciesNames[i],groupCount);
 					cout <<" "<<speciesNames[i];
-				    }catch(ProjectError e){
+				    }catch(ProjectError &e){
 					if(skey == "all")
 					    throw;
 				    }
@@ -134,7 +129,7 @@ void SpeciesCollection::readExtrinsicCFGFile(vector<string> &speciesNames){
 	}
         datei.close();
         datei.clear();
-    } catch (ProjectError e) {
+    } catch (ProjectError &e) {
         cerr << e.getMessage() << endl;
         cerr << "Could not read in file with the configuration of hints: " << filename << endl;
         datei.close();
@@ -163,7 +158,7 @@ void SpeciesCollection::readGFFFile(const char *filename){
         while (datei) {
             try{
                 datei >> f >> comment >> ws;
-            } catch (ProjectError e){}
+            } catch (ProjectError &e){}
 	    // split species name and sequence ID
 	    string completeName=f.seqname;
 	    string speciesName,seqname;                                                                                                          
@@ -193,7 +188,7 @@ void SpeciesCollection::readGFFFile(const char *filename){
 	    }
         }
         datei.close();
-    } catch (ProjectError e) {
+    } catch (ProjectError &e) {
         cerr << e.getMessage() << endl;
         throw e;
     } catch(...) {
